@@ -7,6 +7,8 @@ from typing import TYPE_CHECKING, List, Dict, Any, Iterable, TypeVar, Generic
 
 from checkov.common.graph.graph_builder import Edge
 from checkov.common.graph.graph_builder.utils import run_function_multithreaded
+from checkov.common.graph.graph_builder.graph_components.block_types import BlockType
+
 
 if TYPE_CHECKING:
     from checkov.common.graph.graph_builder.graph_components.blocks import Block  # noqa
@@ -26,6 +28,7 @@ class VariableRenderer(ABC, Generic[_LocalGraph]):
         self.duplicate_iter_count = int(os.getenv("RENDER_EDGES_DUPLICATE_ITER_COUNT", 4))
         self.done_edges_by_origin_vertex: Dict[int, List[Edge]] = {}
         self.replace_cache: List[Dict[str, Any]] = [{}] * len(local_graph.vertices)
+        self.vertices_index_to_render: List[int] = []
 
     def render_variables_from_local_graph(self) -> None:
         self._render_variables_from_edges()
@@ -39,6 +42,9 @@ class VariableRenderer(ABC, Generic[_LocalGraph]):
 
         # all the edges entering `end_vertices`
         edges_to_render = self.local_graph.get_in_edges(end_vertices_indexes)
+        if self.vertices_index_to_render:
+            edges_to_render = self._remove_unrelated_edges(edges_to_render)
+
         end_vertices_indexes = set()
         loops = 0
         evaluated_edges_cache: list[list[Edge]] = [[], []]
@@ -54,7 +60,7 @@ class VariableRenderer(ABC, Generic[_LocalGraph]):
                 break
             evaluated_edges_cache.append(edges_to_render)
 
-            logging.info(f"evaluating {len(edges_to_render)} edges")
+            logging.debug(f"evaluating {len(edges_to_render)} edges")
             # group edges that have the same origin and label together
             edges_groups = self.group_edges_by_origin_and_label(edges_to_render)
             if self.run_async:
@@ -87,10 +93,12 @@ class VariableRenderer(ABC, Generic[_LocalGraph]):
                 logging.warning("Reached 50 graph edge iterations, breaking.")
                 break
 
+        if self.vertices_index_to_render:
+            return
         self.local_graph.update_vertices_configs()
-        logging.info("done evaluating edges")
+        logging.debug("done evaluating edges")
         self.evaluate_non_rendered_values()
-        logging.info("done evaluate_non_rendered_values")
+        logging.debug("done evaluate_non_rendered_values")
 
     @abstractmethod
     def _render_variables_from_vertices(self) -> None:
@@ -101,6 +109,13 @@ class VariableRenderer(ABC, Generic[_LocalGraph]):
         self.evaluate_vertex_attribute_from_edge(inner_edges)
         return inner_edges
 
+    def _remove_unrelated_edges(self, edges_to_render: List[Edge]) -> List[Edge]:
+        new_edges_to_render = []
+        for edge in edges_to_render:
+            if not self.local_graph.vertices[edge.origin] == BlockType.RESOURCE or edge.origin not in self.vertices_index_to_render:
+                new_edges_to_render.append(edge)
+        return new_edges_to_render
+
     @abstractmethod
     def evaluate_vertex_attribute_from_edge(self, edge_list: List[Edge]) -> None:
         pass
