@@ -46,6 +46,7 @@ from checkov.common.output.cyclonedx_consts import (
     BC_SEVERITY_TO_CYCLONEDX_LEVEL,
 )
 from checkov.common.output.record import SCA_PACKAGE_SCAN_CHECK_NAME
+from checkov.common.util.consts import CHECKOV_DISPLAY_REGISTRY_URL
 
 if sys.version_info >= (3, 8):
     from importlib.metadata import version as meta_version
@@ -209,6 +210,9 @@ class CycloneDX:
         else:
             purl_type = FILE_NAME_TO_PURL_TYPE.get(file_name, "generic")
             namespace = f"{self.repo_id}/{resource.file_path}"
+            registry_url = resource.vulnerability_details.get("package_registry")
+            if CHECKOV_DISPLAY_REGISTRY_URL and registry_url:
+                qualifiers = f'registry_url={registry_url}'
         package_group = None
         package_name = resource.vulnerability_details["package_name"]
         package_version = resource.vulnerability_details["package_version"]
