@@ -8,6 +8,8 @@ from abc import ABC, abstractmethod
 from collections.abc import Iterable
 from typing import List, Any, TYPE_CHECKING, TypeVar, Generic, Dict
 
+from checkov.common.graph.db_connectors.igraph.igraph_db_connector import IgraphConnector
+from checkov.common.graph.db_connectors.networkx.networkx_db_connector import NetworkxConnector
 from checkov.common.graph.graph_builder import CustomAttributes
 from checkov.common.util.tqdm_utils import ProgressBar
 
@@ -19,7 +21,7 @@ if TYPE_CHECKING:
     from checkov.common.checks_infra.registry import Registry
     from checkov.common.graph.checks_infra.registry import BaseRegistry
     from checkov.common.graph.graph_manager import GraphManager  # noqa
-    from checkov.common.typing import _CheckResult
+    from checkov.common.typing import _CheckResult, LibraryGraphConnector
 
 _GraphManager = TypeVar("_GraphManager", bound="GraphManager[Any, Any]|None")
 
@@ -56,11 +58,20 @@ class BaseRunner(ABC, Generic[_GraphManager]):
     external_registries: list[BaseRegistry] | None = None
     graph_manager: _GraphManager | None = None
     graph_registry: Registry | None = None
+    db_connector: LibraryGraphConnector
 
     def __init__(self, file_extensions: Iterable[str] | None = None, file_names: Iterable[str] | None = None):
         self.file_extensions = file_extensions or []
         self.file_names = file_names or []
         self.pbar = ProgressBar(self.check_type)
+        db_connector_class: "type[NetworkxConnector | IgraphConnector]" = NetworkxConnector
+        graph_framework = os.getenv("CHECKOV_GRAPH_FRAMEWORK", "NETWORKX")
+        if graph_framework == "IGRAPH":
+            db_connector_class = IgraphConnector
+        elif graph_framework == "NETWORKX":
+            db_connector_class = NetworkxConnector
+
+        self.db_connector = db_connector_class()
 
     @abstractmethod
     def run(
