@@ -38,6 +38,7 @@ def create_report_license_record(
         file_abs_path: str,
         check_class: str,
         licenses_status: _LicenseStatus,
+        package_registry: str,
         sca_details: SCADetails | None = None,
 ) -> Record:
     package_name = licenses_status["package_name"]
@@ -59,6 +60,7 @@ def create_report_license_record(
     details = {
         "package_name": package_name,
         "package_version": package_version,
+        "package_registry": package_registry,
         "license": licenses_status["license"],
         "status": status,
         "policy": policy,
@@ -117,6 +119,7 @@ def create_report_cve_record(
         check_class: str,
         vulnerability_details: dict[str, Any],
         licenses: str,
+        package_registry: str,
         root_package_version: str | None = None,
         root_package_name: str | None = None,
         root_package_fixed_version: str | None = None,
@@ -157,6 +160,7 @@ def create_report_cve_record(
         "severity": severity,
         "package_name": package_name,
         "package_version": package_version,
+        "package_registry": package_registry,
         "package_type": package_type,
         "link": vulnerability_details.get("link"),
         "cvss": vulnerability_details.get("cvss"),
@@ -201,6 +205,7 @@ def _add_to_report_licenses_statuses(
         scanned_file_path: str,
         rootless_file_path: str,
         runner_filter: RunnerFilter,
+        packages_map: dict[str, dict[str, Any]],
         license_statuses: list[_LicenseStatus],
         sca_details: SCADetails | None = None,
         report_type: str | None = None,
@@ -215,7 +220,8 @@ def _add_to_report_licenses_statuses(
             license_status["package_version"],
             license_status["license"],
         )
-        licenses_per_package_map[get_package_alias(package_name, package_version)].append(license)
+        package_alias = get_package_alias(package_name, package_version)
+        licenses_per_package_map[package_alias].append(license)
 
         policy = license_status["policy"]
 
@@ -224,6 +230,7 @@ def _add_to_report_licenses_statuses(
             file_abs_path=scanned_file_path,
             check_class=check_class or "",
             licenses_status=license_status,
+            package_registry=packages_map.get(package_alias, {}).get("registry", ""),
             sca_details=sca_details,
         )
 
@@ -255,6 +262,7 @@ def add_to_reports_cves_and_packages(
         runner_filter: RunnerFilter,
         vulnerabilities: list[dict[str, Any]],
         packages: list[dict[str, Any]],
+        packages_map: dict[str, dict[str, Any]],
         licenses_per_package_map: dict[str, list[str]],
         dependencies: dict[str, List[int]] | None = None,
         sca_details: SCADetails | None = None,
@@ -275,11 +283,10 @@ def add_to_reports_cves_and_packages(
         else:
             # adding resources without cves for adding them also in the output-bom-repors
             add_extra_resources_to_report(report, scanned_file_path, rootless_file_path,
-                                          package_name, package_version, package_alias,
-                                          licenses_per_package_map, sca_details)
+                                          package, package_alias, licenses_per_package_map, sca_details)
 
     if is_dependency_tree_flow:
-        add_to_reports_dependency_tree_cves(check_class, licenses_per_package_map, packages, report,
+        add_to_reports_dependency_tree_cves(check_class, packages_map, licenses_per_package_map, packages, report,
                                             root_packages_list, rootless_file_path, runner_filter,
                                             scanned_file_path, scan_data_format, sca_details, report_type)
     else:  # twistlock scan results.
@@ -288,6 +295,7 @@ def add_to_reports_cves_and_packages(
             add_cve_record_to_report(vulnerability_details=vulnerability,
                                      package_name=package_name,
                                      package_version=package_version,
+                                     packages_map=packages_map,
                                      rootless_file_path=rootless_file_path,
                                      scanned_file_path=scanned_file_path,
                                      check_class=check_class or "",
@@ -299,8 +307,9 @@ def add_to_reports_cves_and_packages(
                                      report=report)
 
 
-def add_to_reports_dependency_tree_cves(check_class: str | None, licenses_per_package_map: dict[str, list[str]],
-                                        packages: list[dict[str, Any]], report: Report, root_packages_list: list[int],
+def add_to_reports_dependency_tree_cves(check_class: str | None, packages_map: dict[str, dict[str, Any]],
+                                        licenses_per_package_map: dict[str, list[str]], packages: list[dict[str, Any]],
+                                        report: Report, root_packages_list: list[int],
                                         rootless_file_path: str, runner_filter: RunnerFilter, scanned_file_path: str,
                                         scan_data_format: ScanDataFormat = ScanDataFormat.TWISTCLI,
                                         sca_details: SCADetails | None = None, report_type: str | None = None) -> None:
@@ -319,7 +328,7 @@ def add_to_reports_dependency_tree_cves(check_class: str | None, licenses_per_pa
                 continue
 
             add_cve_record_to_report(vulnerability_details=cve, package_name=root_package['name'],
-                                     package_version=root_package['version'],
+                                     package_version=root_package['version'], packages_map=packages_map,
                                      rootless_file_path=rootless_file_path, scanned_file_path=scanned_file_path,
                                      check_class=check_class, licenses_per_package_map=licenses_per_package_map,
                                      runner_filter=runner_filter, sca_details=sca_details,
@@ -335,7 +344,7 @@ def add_to_reports_dependency_tree_cves(check_class: str | None, licenses_per_pa
                     root_package_fixed_version = indirect_packages[cve_alias]['fixVersion']
 
                 add_cve_record_to_report(vulnerability_details=dep_cve, package_name=dep['name'],
-                                         package_version=dep['version'],
+                                         package_version=dep['version'], packages_map=packages_map,
                                          rootless_file_path=rootless_file_path, scanned_file_path=scanned_file_path,
                                          check_class=check_class, licenses_per_package_map=licenses_per_package_map,
                                          runner_filter=runner_filter, sca_details=sca_details,
@@ -346,20 +355,21 @@ def add_to_reports_dependency_tree_cves(check_class: str | None, licenses_per_pa
 
 
 def add_cve_record_to_report(vulnerability_details: dict[str, Any], package_name: str, package_version: str,
-                             rootless_file_path: str,
+                             packages_map: dict[str, dict[str, Any]], rootless_file_path: str,
                              scanned_file_path: str, check_class: Optional[str],
                              licenses_per_package_map: dict[str, list[str]], runner_filter: RunnerFilter,
                              sca_details: Optional[SCADetails], scan_data_format: ScanDataFormat,
                              report_type: Optional[str], report: Report,
                              root_package_version: str | None = None, root_package_name: str | None = None,
                              root_package_fixed_version: str | None = None) -> None:
+    package_alias = get_package_alias(package_name, package_version)
     cve_record = create_report_cve_record(
         rootless_file_path=rootless_file_path,
         file_abs_path=scanned_file_path,
         check_class=check_class or "",
         vulnerability_details=vulnerability_details,
-        licenses=format_licenses_to_string(
-            licenses_per_package_map[get_package_alias(package_name, package_version)]),
+        licenses=format_licenses_to_string(licenses_per_package_map[package_alias]),
+        package_registry=packages_map.get(package_alias, {}).get("registry", ""),
         runner_filter=runner_filter,
         sca_details=sca_details,
         scan_data_format=scan_data_format,
@@ -413,24 +423,20 @@ def create_vulnerable_packages_dict(vulnerabilities: list[dict[str, Any]], packa
 
             package_alias = get_package_alias(package["name"], package["version"])
             for cve_idx in package.get('cves_index', []):
-                if package_alias not in vulnerable_packages:
-                    vulnerable_packages[package_alias] = []
-                vulnerable_packages[package_alias].append(vulnerabilities[cve_idx])
+                vulnerable_packages.setdefault(package_alias, []).append(vulnerabilities[cve_idx])
     else:
         for vulnerability in vulnerabilities:
             package_alias = get_package_alias(vulnerability["packageName"], vulnerability["packageVersion"])
-            if package_alias not in vulnerable_packages:
-                vulnerable_packages[package_alias] = []
-
-            vulnerable_packages[package_alias].append(vulnerability)
+            vulnerable_packages.setdefault(package_alias, []).append(vulnerability)
 
     return vulnerable_packages, root_packages_list
 
 
 def add_extra_resources_to_report(report: Report, scanned_file_path: str, rootless_file_path: str,
-                                  package_name: str, package_version: str, package_alias: str,
+                                  package: dict[str, Any], package_alias: str,
                                   licenses_per_package_map: dict[str, list[str]],
                                   sca_details: Optional[SCADetails]) -> None:
+    package_name, package_version, package_registry = package["name"], package["version"], package.get("registry", "")
     report.extra_resources.add(
         ExtraResource(
             file_abs_path=scanned_file_path,
@@ -439,6 +445,7 @@ def add_extra_resources_to_report(report: Report, scanned_file_path: str, rootle
             vulnerability_details={
                 "package_name": package_name,
                 "package_version": package_version,
+                "package_registry": package_registry,
                 "licenses": format_licenses_to_string(
                     licenses_per_package_map[package_alias]),
                 "package_type": get_package_type(package_name, package_version, sca_details),
@@ -460,9 +467,10 @@ def add_to_report_sca_data(
         sca_details: SCADetails | None = None,
         report_type: str | None = None,
 ) -> None:
+    packages_map: dict[str, dict[str, Any]] = {get_package_alias(p["name"], p["version"]): p for p in packages}
     licenses_per_package_map: dict[str, list[str]] = \
         _add_to_report_licenses_statuses(report, check_class, scanned_file_path, rootless_file_path, runner_filter,
-                                         license_statuses, sca_details, report_type)
+                                         packages_map, license_statuses, sca_details, report_type)
     # if dependencies is empty list it means we got results via DependencyTree scan but no dependencies have found.
     add_to_reports_cves_and_packages(report=report, check_class=check_class,
                                      scanned_file_path=scanned_file_path,
@@ -470,6 +478,7 @@ def add_to_report_sca_data(
                                      runner_filter=runner_filter,
                                      vulnerabilities=vulnerabilities,
                                      packages=packages,
+                                     packages_map=packages_map,
                                      licenses_per_package_map=licenses_per_package_map,
                                      sca_details=sca_details,
                                      report_type=report_type,
