@@ -115,6 +115,12 @@ class ExtArgumentParser(configargparse.ArgumentParser):
             action="version",
             version=version,
         )
+        self.add(
+            "--support",
+            action="store_true",
+            help="Enable debug logs and upload the logs to the server. Requires a Bridgecrew or Prisma Cloud API key.",
+            default=None
+        )
         self.add(
             "-d",
             "--directory",
