@@ -75,18 +75,22 @@ def is_schema_valid(config: dict[str, Any] | list[dict[str, Any]]) -> bool:
 
 
 def get_gha_files_definitions(root_folder: str | Path,
-                              files: "list[Path] | None" = None,
+                              files: "list[str] | None" = None,
                               runner_filter: RunnerFilter | None = None,) -> tuple[dict[str, Any], dict[str, Any]]:
     definitions = {}
     definitions_raw = {}
     file_paths = get_scannable_file_paths(root_folder=root_folder)
+    files_set = set(files) if files else set()
 
     for file_path in file_paths:
-        result = parse_file(f=file_path)
-        # result should be tuple of dict representing the file payload structure and list of lines of the payload
-        if result is not None:
-            definitions[str(file_path)] = result[0]
-            definitions_raw[str(file_path)] = result[1]
+        str_file_path = str(file_path)
+        should_parse: bool = str_file_path in files_set if files_set else True
+        if should_parse:
+            result = parse_file(f=file_path)
+            # result should be tuple of dict representing the file payload structure and list of lines of the payload
+            if result is not None:
+                definitions[str_file_path] = result[0]
+                definitions_raw[str_file_path] = result[1]
 
     return definitions, definitions_raw
 
@@ -117,15 +121,23 @@ def build_gha_definitions_context(definitions: dict[str, dict[str, Any]], defini
                             [file_path, str(file_path_definition), str(attribute)],
                             {"start_line": start_line, "end_line": end_line, "code_lines": code_lines},
                         )
-                elif isinstance(definition, str):
+                elif isinstance(definition, (str, list)):
                     for line_tuple in definitions_raw[file_path]:
-                        if file_path_definition in line_tuple[1] and definition in line_tuple[1]:
+                        if file_path_definition in line_tuple[1] and definition_locator_helper(definition, line_tuple[1]):
                             code_lines = definitions_raw[file_path][line_tuple[0] - 1:line_tuple[0]]
                             dpath.new(
                                 definitions_context,
-                                [file_path, str(file_path_definition), definition],
+                                [file_path, str(file_path_definition), str(definition)],
                                 {"start_line": line_tuple[0], "end_line": line_tuple[0] + 1, "code_lines": code_lines},
                             )
                             break
 
     return definitions_context
+
+
+def definition_locator_helper(definition: str | list[str], target: str) -> bool:
+    if isinstance(definition, str):
+        return definition in target
+    elif isinstance(definition, list):
+        return all(item in target for item in definition)
+    return False
