@@ -30,10 +30,10 @@ class AbsSecurityGroupUnrestrictedIngress(BaseResourceCheck):
 
     def scan_protocol_conf(self, protocol_name):
         """ scan tcp_options configuration"""
-        if 'source_port_range' not in protocol_name[0]:
+        if 'destination_port_range' not in protocol_name[0]:
             return False
-        max_port = force_int(protocol_name[0]['source_port_range'][0]['max'][0])
-        min_port = force_int(protocol_name[0]['source_port_range'][0]['min'][0])
+        max_port = force_int(protocol_name[0]['destination_port_range'][0]['max'][0])
+        min_port = force_int(protocol_name[0]['destination_port_range'][0]['min'][0])
         if max_port and min_port and min_port <= self.port <= max_port:
             return False
         return True
